USE [igops]
GO

DROP VIEW IF EXISTS cpol_violations_v
DROP VIEW IF EXISTS cpol_admins_v
GO

CREATE VIEW cpol_admins_v AS
 SELECT DISTINCT 
	admins.display_name AS policy_admin, 
	admins.unique_user_id AS admin_id, 
	cp.id AS policy_id
 FROM suser admins
 LEFT JOIN certification_policy_admin cpa ON cpa.admin_unique_id = admins.unique_user_id AND admins.effective = 1
 LEFT JOIN certification_policy cp ON cpa.cert_policy_id = cp.id 
 WHERE cp.is_active = 1
 GO

 CREATE VIEW cpol_violations_v AS
SELECT
	cp.created_by,
	cp.changed_by,
	cp.id,
	cp.unique_id AS cert_unique_id,
	cp.name AS cpol,
	cp.description,
	cp.validity_period,
	admins.admin_name AS administrators,
	cp.risk,
	cp.cp_total_violation,
	cp.deleted,
	cp.remediation_type,
	rd.name AS review_name,
	rd.id AS review_id,
	rd.description AS review_description,
	rd.review_type,
	rd.review_target_type,
	cpv.violation_type,
	cpv.violation_status,
	cpv.created_date,
	cpv.resolved_date,
	cpv.last_detected_date,
	saccount.name AS account_violator,
	saccount.unique_account_id,
	saccount.description AS account_desc,
	cust.account_custodian,
	spermission.name AS permission_violator,
	spermission.unique_permission_id,
	spermission.description AS permission_desc,
	suser.display_name AS user_violator,
	suser.user_id,
	suser.unique_user_id,
	suser.display_description AS user_desc,
	sup.display_name AS supervisor_name,
	sup.unique_user_id AS supervisor_id,
	role.name AS role_violator,
	role.unique_policy_id AS role_qid,
	role.description AS role_desc,
	brole.name AS brole_violator,
	brole.unique_id AS brole_qid,
	brole.description AS brole_desc
FROM certification_policy cp
	LEFT JOIN remediation remed ON cp.unique_id = remed.policy_unique_id AND remed.is_active = 1
	LEFT JOIN cert_policy_review_defs cprd ON cp.id = cprd.cert_policy_id
	LEFT JOIN review_definition rd ON cprd.review_definition_unique_id = rd.unique_review_def_id AND rd.is_active = '1'
	JOIN cert_policy_violation cpv ON rd.unique_review_def_id = cpv.review_definition_unique_id
	LEFT JOIN (SELECT cp.id, STUFF((SELECT DISTINCT ' | ' + admins.display_name 
				FROM suser admins
				LEFT JOIN certification_policy_admin cpa ON cpa.admin_unique_id = admins.unique_user_id AND admins.effective = 1
				LEFT JOIN certification_policy cp2 ON cpa.cert_policy_id = cp2.id
				WHERE cp2.is_active = 1 AND cp2.id = cp.id FOR XML PATH('')), 1,3,'') admin_name 
				FROM certification_policy cp) admins ON cp.id = admins.id
	LEFT JOIN saccount ON cpv.unique_account_id = saccount.unique_account_id AND saccount.effective = 1
	LEFT JOIN (SELECT DISTINCT sacc.unique_account_id, STUFF((SELECT DISTINCT ' | ' + cust.display_name 
				FROM saccount sacc2
				LEFT JOIN resolved_saccount_owner rso ON sacc.id = rso.account AND sacc2.effective = 1
				LEFT JOIN suser cust ON rso.owner_unique_id = cust.unique_user_id
				WHERE cust.effective = 1 AND sacc2.unique_account_id = sacc.unique_account_id FOR XML PATH('')), 1,3,'') account_custodian
				FROM saccount sacc WHERE sacc.unique_account_id is not null AND sacc.effective = 1) cust ON cust.unique_account_id = saccount.unique_account_id
	LEFT JOIN spermission ON cpv.unique_permission_id = spermission.unique_permission_id AND spermission.effective = 1
	LEFT JOIN suser ON cpv.unique_user_id = suser.unique_user_id AND suser.effective = 1
	LEFT JOIN suser sup ON sup.unique_user_id = suser.supervisor_unique_id AND sup.effective = 1
	LEFT JOIN role_policy role ON cpv.role_id = role.id AND role.state = 'ACTIVE' AND role.deleted = 0
	LEFT JOIN business_role brole ON cpv.business_role_id = brole.id
WHERE cp.is_active = 1
GO

GRANT SELECT ON cpol_violations_v TO ig_report_role
GRANT SELECT ON cpol_admins_v TO ig_report_role
GO